database

package
v1.6.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 17, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package database implements the data reverse lookup.

Source: https://github.com/s0md3v/Bolt/blob/master/db/hashes.json

Example
for v := range Lookup("1234567890abcd") {
	fmt.Println(v)
}
Output:
Cisco Type 7
BigCrypt

Index

Examples

Constants

This section is empty.

Variables

var Entries = []Entry{}/* 145 elements not displayed */

Entries of data patterns.

Functions

func Lookup

func Lookup(v string) <-chan string

Lookup will write the found matches into the returned channel.

The returned channel will be closed at the end of the operation.

Types

type Entry

type Entry struct {
	// Hash regex.
	Regex *regexp.Regexp
	// Hash names.
	Names []string
}

Entry of data pattern.

Jump to